<?php
namespace App\Services\User;

use App\Services\User\IUserService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use App\Models\AdminModel;
use Illuminate\Support\Facades\Cache;

class UserService implements IUserService{
    private $time;
    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 新增用户
     * @return int
     * @date 2021/07/29
     * @author live
     */
    public function getUserAdd($postData)
    {
        $verity = AdminModel::where('name',$postData['name'])->select('id')->first();
        if(!$verity){
            $row = new AdminModel();
            $row->name = $postData['name'] ?? '';
            $row->real_name = $postData['realName'] ?? '';
            $row->password = MD5($postData['pwd']);
            $row->phone = $postData['phone'] ?? '';
            $row->email = $postData['email'] ?? '';
            $row->remark = $postData['remark'] ?? '';
            $row->is_admin = 1;
            if( $row->save()) return $row->id;
            throw new Exception(config('msg.common.1006'),1006);
        }
        throw new Exception(config('msg.common.1005'),1005);
    }


    /**
     * 用户列表
     * @return araay
     * @date 2021/07/29
     * @author live
     */
    public function getUserList($postData)
    {
        $key = $postData['key'] ?? '';
        $pagePerNum = $postData['pageSize'] ?? 20;
        $currentPage = $postData['page'] ?? 1;

        $users = AdminModel::when($key != '', function ($query) use ($key) {
            return $query->where('name', 'like',$key.'%')->orWhere('real_name', 'like',$key.'%');
        })->select('id','name','real_name','phone','email','status','created_at')->orderBy('id','DESC')->paginate($pagePerNum, ['*'], 'currentPage',$currentPage);
        $array['totalNum'] = $users->total();
        $array['totalPage'] = $users->lastPage();
        foreach($users as $user){
            $tem['id'] = $user->id;
            $tem['name'] = $user->name;
            $tem['realName'] = $user->real_name;
            $tem['phone'] = $user->phone;
            $tem['email'] = $user->email;
            $tem['status'] = $user->status;
            $tem['created_at'] = Carbon::parse($user->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($users,$user);
        return $array;
    }

    /**
     * 删除用户
     * @return araay
     * @date 2021/07/29
     * @author live
     */
    public function getUserDel($postData)
    {
        $user = AdminModel::where('id',$postData['id'])->first();
        if(!$user) throw new Exception(config('msg.common.1002'),1002);
        if($user->delete()) return true;
        throw new Exception(config('msg.common.1003'),1003);
    }

    /**
     * 修改用户登录密码
     * @return araay
     * @date 2021/07/29
     * @author live
     */
    public function getResetUserPwd($postData)
    {
        $user = AdminModel::where('id',$postData['id'])->first();
        if($user->status == 0) throw new Exception(config('msg.common.1008'),1008);
        if(!$user) throw new Exception(config('msg.common.1002'),1002);
        $user->password = MD5($postData['pwd']);
        if($user->token != '') $user->expire_time = strtotime($this->time);
        if($user->save()) return true;
        throw new Exception(config('msg.common.1003'),1003);
    }

    /**
     * 设置用户状态
     * @return araay
     * @date 2021/07/29
     * @author live
     */
    public function getSetStatus($postData)
    {
        $user = AdminModel::where('id',$postData['id'])->first();
        if(!$user) throw new Exception(config('msg.common.1002'),1002);
        if($postData['status'] == 1){
            if($user->status == 1) throw new Exception(config('msg.common.1009'),1009);
            $user->status = 1;
        }
        if($postData['status'] == 2){
            if($user->status == 0) throw new Exception(config('msg.common.1009'),1009);
            $user->status = 0;
        }

        if($user->save()) return true;
        throw new Exception(config('msg.common.1003'),1003);
    }


    /**
     * 用户登录
     * @return araay
     * @date 2021/07/29
     * @author live
     */
    public function getLogin($postData){
        $array['token'] = '';
        $user = AdminModel::where('name',$postData['name'])->where('password',MD5($postData['pwd']))->first();
        if(!$user) throw new Exception(config('msg.common.1007'),1007);
        $userToken = Str::random(128);

        $user->token = $userToken;
        $user->expire_time = strtotime($this->time) + 10800;
        $user->refresh_time = strtotime($this->time) + 86400;
        $user->save();

        $array['token'] = $userToken;
        $array['id'] = $user->id;
        $array['name'] = $user->name;
        $array['realName'] = $user->real_name;
        unset($user,$userToken);
        return $array;
    }

    /**
     * 刷新用户token
     * @return araay
     * @date 2021/07/29
     * @author live
     */
    public function getRefreshToken($userToken)
    {
        $array['token'] = '';
        $user =  AdminModel::where('token',$userToken)->first();
        if(!$user) if(!$user) throw new Exception(config('msg.common.401'),401);
        if(strtotime($this->time) > $user->refresh_time) throw new Exception(config('msg.common.1011'),1011);

        $userToken = Str::random(128);
        $user->token = $userToken;
        $user->expire_time = strtotime($this->time) + 10800;
        $user->refresh_time = strtotime($this->time) + 86400;
        $user->save();
        $array['token'] = $userToken;
        unset($user,$userToken);
        return $array;
    }

    /**
     * 退出登录
     * @return araay
     * @date 2021/02/25
     * @author live
     */
    public function getLogout($token)
    {
        $user = AdminModel::where('token',$token)->select('id','token')->first();
        $user->token = '';
        $user->expire_time = 0;
        $user->refresh_time = 0;
        $user->save();
        return true;
    }

}