<?php
namespace App\Services\White;

use App\Services\White\IWhiteService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use App\Models\WithdrawWhiteListModel;
use App\Models\AccountModel;
use Illuminate\Support\Facades\Cache;

class WhiteService implements IWhiteService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 新增白名单
     * @return int
     * @date 2021/07/29
     * @author live
     */
    public function getWhiteAdd($postData)
    {
        $verity = WithdrawWhiteListModel::where('uid', $postData['uid'])->select('serial')->first();
        if (!$verity) {
            $account = AccountModel::where('platform_id', $postData['uid'])->first();
            if(!$account) throw new Exception(config('msg.common.1012'), 1012);
            $row = new WithdrawWhiteListModel();
            $row->name = $postData['name'] ?? '';
            $row->uid = $postData['uid'] ?? '';
            $row->open_id = $account->user_id ?? '';
            $row->reg_time = $account->create_time ?? $this->time;
            $row->op_user = $postData['user'] ?? '';
            $row->add_time = $this->time;
            if ($row->save()) return $row->serial;
            throw new Exception(config('msg.common.1006'), 1006);
        }
        throw new Exception(config('msg.common.1005'), 1005);
    }


    /**
     * 白名单列表
     * @return araay
     * @date 2021/07/29
     * @author live
     */
    public function getWhiteList($postData)
    {
        $status = $postData['status'] ?? 0;
        $name = $postData['name'] ?? '';
        $pagePerNum = $postData['pageSize'] ?? 20;
        $currentPage = $postData['page'] ?? 1;

        $lists = WithdrawWhiteListModel::when($name != '', function ($query) use ($name) {
            return $query->where('name', 'like', $name . '%');
        })->when($status > 0, function ($query) use ($status) {
            return $query->where('status',$status);
        })->select('serial', 'name', 'uid', 'status', 'op_user', 'add_time')->orderBy('serial', 'DESC')->paginate($pagePerNum, ['*'], 'currentPage', $currentPage);
        $array['totalNum'] = $lists->total();
        $array['totalPage'] = $lists->lastPage();
        foreach ($lists as $list) {
            $tem['id'] = $list->serial;
            $tem['name'] = $list->name;
            $tem['account'] = $list->uid;
            $tem['status'] = $list->status;
            $tem['optionUser'] = $list->op_user;
            $tem['addTime'] = $list->add_time;
            $array['data'][] = $tem;
        }
        unset($lists, $list);
        return $array;
    }

    /**
     * 删除白名单
     * @return araay
     * @date 2021/07/29
     * @author live
     */
    public function getWhiteDel($postData)
    {
        $list = WithdrawWhiteListModel::where('serial', $postData['id'])->first();
        if (!$list) throw new Exception(config('msg.common.1002'), 1002);
        if ($list->delete()) return true;
        throw new Exception(config('msg.common.1003'), 1003);
    }


    /**
     * 设置白名单状态
     * @return araay
     * @date 2021/07/29
     * @author live
     */
    public function getSetStatus($postData)
    {
        $list = WithdrawWhiteListModel::where('serial', $postData['id'])->first();
        if (!$list) throw new Exception(config('msg.common.1002'), 1002);

        if($list->status == $postData['status']) throw new Exception(config('msg.common.1009'), 1009);
        $list->status = $postData['status'];
        $list->add_time = $this->time;
        if ($list->save()) return true;
        throw new Exception(config('msg.common.1003'), 1003);
    }

}